<?php

namespace Drupal\one\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 */
class SettingsForm extends ConfigFormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'one.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('one.settings');

    $node_types = \Drupal\node\Entity\NodeType::loadMultiple();
    foreach ($node_types as $node_type) {
      //$options[$node_type->id()] = $node_type->label();
      $node_type_machine_name = $node_type->id();
      $field_defs = \Drupal::service('entity_field.manager')->getFieldDefinitions('node', $node_type_machine_name);
      $image_fields = array();
      $text_fields = array();
      $link_fields = array();
      $video_embed_fields = array();
      foreach ($field_defs as $field_def) {
        $field_type = $field_def->getType();
        $field_name = $field_def->getName();
        if($field_type == "image"){
          $image_fields[$field_name] = $field_name;
        }elseif($field_type == "text_with_summary"){
          $text_fields[$field_name] = $field_name;
        }elseif($field_type == "link"){
          $link_fields[$field_name] = $field_name;
        }elseif($field_type == "video_embed_field"){
          $video_embed_fields[$field_name] = $field_name;
        }else{
          // video_embed_field
          //dsm("$field_type $field_name");
        }
      }
      $form['content_type_'.$node_type_machine_name] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Content Type '.$node_type->label()),
        '#description' => $this->t('Settings for Content Type'),
        '#weight' => '0',
      ];

      if(!empty($image_fields)){
        $form['content_type_'.$node_type_machine_name][$node_type_machine_name.'_field_image'] = [
          '#type' => 'select',
          '#title' => $this->t('Image'),
          '#description' => $this->t('Select to enable this Content Type'),
          '#options' => $image_fields,
          '#default_value' => $config->get($node_type_machine_name.'_field_image') ?: '',
          '#weight' => '0',
        ];
      }
      if(!empty($text_fields)){
        $form['content_type_'.$node_type_machine_name][$node_type_machine_name.'_field_body'] = [
          '#type' => 'select',
          '#title' => $this->t('HTML body'),
          '#description' => $this->t('Select to enable this Content Type'),
          '#options' => $text_fields,
          '#default_value' => $config->get($node_type_machine_name.'_field_body') ?: '',
          '#weight' => '0',
        ];
      }
      if(!empty($video_embed_fields)){
        $form['content_type_'.$node_type_machine_name][$node_type_machine_name.'_field_video_embed'] = [
        '#type' => 'select',
        '#title' => $this->t('Embedded Video'),
        '#description' => $this->t('Embedded Video like youtube'),
        '#options' => $video_embed_fields,
        '#default_value' => $config->get($node_type_machine_name.'_field_video_embed') ?: '',
        '#weight' => '0',
        ];
      }
      if(!empty($link_fields)){
        $form['content_type_'.$node_type_machine_name][$node_type_machine_name.'_field_remote_image'] = [
          '#type' => 'select',
          '#title' => $this->t('Remote Image URL'),
          '#description' => $this->t('Select to enable this Content Type'),
          '#options' => $link_fields,
          '#default_value' => $config->get($node_type_machine_name.'_field_remote_image') ?: '',
          '#weight' => '0',
        ];
        $form['content_type_'.$node_type_machine_name][$node_type_machine_name.'_field_remote_page'] = [
          '#type' => 'select',
          '#title' => $this->t('Remote page URL'),
          '#description' => $this->t('For example link URL to read more news on an external site'),
          '#options' => $link_fields,
          '#default_value' => $config->get($node_type_machine_name.'_field_remote_page') ?: '',
          '#weight' => '0',
        ];
      }
      $form['content_type_'.$node_type_machine_name][$node_type_machine_name.'_enable_content_type'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable Content Type'),
        '#description' => $this->t('Select to enable this Content Type'),
        '#default_value' => $config->get($node_type_machine_name.'_enable_content_type') ?: 0,
        '#weight' => '0',
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = $this->config('one.settings');
    $node_types = \Drupal\node\Entity\NodeType::loadMultiple();
    foreach ($node_types as $node_type) {
      $node_type_machine_name = $node_type->id();

      $config->set($node_type_machine_name.'_enable_content_type', $values[$node_type_machine_name.'_enable_content_type']);
      if(isset($values[$node_type_machine_name.'_field_body'])){
        $config->set($node_type_machine_name.'_field_body', $values[$node_type_machine_name.'_field_body']);
      }
      if(isset($values[$node_type_machine_name.'_field_image'])){
        $config->set($node_type_machine_name.'_field_image', $values[$node_type_machine_name.'_field_image']);
      }
      if(isset($values[$node_type_machine_name.'_field_remote_image'])){
        $config->set($node_type_machine_name.'_field_remote_image', $values[$node_type_machine_name.'_field_remote_image']);
      }
      if(isset($values[$node_type_machine_name.'_field_remote_page'])){
        $config->set($node_type_machine_name.'_field_remote_page', $values[$node_type_machine_name.'_field_remote_page']);
      }
      if(isset($values[$node_type_machine_name.'_field_video_embed'])){
        $config->set($node_type_machine_name.'_field_video_embed', $values[$node_type_machine_name.'_field_video_embed']);
      }
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
